#include <Wire.h>
#include <LiquidCrystal_PCF8574.h>
#include <ESP8266WiFi.h>
 
const char* ssid     = ""; // nazwa sieci
const char* password = ""; // hasło

const char* host = "192.168.1.105"; // adres serwera, na któym jest skrypt php
String url = "/Przystanki/getDisplayData.php"; // ścieżka do skryptu

String data = "";

const byte BUTTON = D6;
const byte LED = D4;

LiquidCrystal_PCF8574 lcd(0x27);
 
void setup() {
  pinMode(BUTTON, INPUT);
  pinMode(LED, OUTPUT);
  digitalWrite(LED, HIGH);
  
  Wire.begin();
  Wire.beginTransmission(0x27);
  lcd.begin(16, 2);
  lcd.setBacklight(255);

  lcd.print("Laczenie z:");
  lcd.setCursor(0,1);
  lcd.print(ssid);
  
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) delay(100);

  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("Polaczono!");
  lcd.setCursor(0,1);
  lcd.print(WiFi.localIP());

  delay(500);

  lcd.clear();
  lcd.setBacklight(0);
}
 
void loop() {
  if(!digitalRead(BUTTON)) {
    lcd.setBacklight(255);
    for(int x = 0; x < 4; x++) {
      digitalWrite(LED, LOW);
      getData();
      digitalWrite(LED, HIGH);
      delay(15*1000);
    }
    lcd.setBacklight(0);
    lcd.clear();
  }
}

void printDataToLCD(String data) {
  String trams[2], times[2];
  data = data.substring(5);

  int line = 0;
  bool isTram = true;

  for(int x = 0; x < 2; x++) {
    trams[x] = "";
    times[x] = "";
  }
  
  for(int x = 0; x < data.length(); x++) {
    if(data.charAt(x) == '+') {
      isTram = true;
      line++;
      continue;
    }

    if(data.charAt(x) == '-') {
      isTram = false;
      continue;
    }

    if(line >= 2) break;
    
    if(isTram) {
      trams[line] += data.charAt(x);
    } else {
      times[line] += data.charAt(x);
    }
  }

  lcd.clear();
  for(int x = 0; x < 2; x++) {
    lcd.setCursor(0,x);
    lcd.print(trams[x]);
    lcd.setCursor(15 - times[x].length(),x);
    lcd.print(times[x]);
  }
}

void getData() {
  WiFiClient client;
  if(!client.connect(host, 80)) {
    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("Blad sieci!");
    return;
  }
  
  Serial.println(url);
  client.print(String("GET ") + url + " HTTP/1.1\r\n" +
               "Host: " + host + "\r\n" + 
               "Connection: close\r\n\r\n");
  delay(500);

  bool gotCorrectData = false;
  while(client.available()){
    String line = client.readStringUntil('\r');
    line.trim();
    if(line.startsWith("DATA:")) {
      printDataToLCD(line);
      gotCorrectData = true;
    }
  }

  if(!gotCorrectData) {
    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("Bledne dane!");
    return;
  }
}

